==> centreon-web-24.04.19.tar.gz: centreon-web-24.04.19/www/front_src/src/ResourceAccessManagement/translatedLabels.ts <==
export const labelResourceAccessRules = 'Resource access rules';
export const labelName = 'Name';
export const labelDescription = 'Description';
export const labelActions = 'Actions';
export const labelStatus = 'Status';
export const labelSearch = 'Search';
export const labelAdd = 'Add';
export const labelCreateResourceAccessRule =
  'Create a new resource access rule';
export const labelEditResourceAccessRule = 'Edit resource access rule';
export const labelRuleProperies = 'Rule properties';
export const labelAddResourceDatasets = 'Add resource datasets';
export const labelContacts = 'Contacts';
export const labelContactGroups = 'Contact Groups';
export const labelContactsAndContactGroups = 'Contacts/Contact groups';
export const labelResourceAccessRuleAddedSuccess =
  'The resource access rule was successfully created';
export const labelResourceAccessRuleEditedSuccess =
  'The resource access rule was successfully updated';
export const labelRequired = 'Required';
export const labelNameAlreadyExists = 'This name already exists';
export const labelSave = 'Save';
export const labelExit = 'Exit';
export const labelAddNewDataset = 'Add new dataset';
export const labelAddFilter = 'Add filter';
export const labelChooseAtLeastOneContactOrContactGroup =
  'Choose at least one contact or contact group';
export const labelHost = 'Host';
export const labelHostCategory = 'Host category';
export const labelHostGroup = 'Host group';
export const labelMetaService = 'Metaservice';
export const labelService = 'Service';
export const labelServiceCategory = 'Service category';
export const labelServiceGroup = 'Service group';
export const labelPleaseSelectAResource = 'Please select a resource';
export const labelDelete = 'Delete';
export const labelSelectResourceType = 'Select resource type';
export const labelSelectResource = 'Select resource';
export const labelActiveOrInactive = 'Active / Inactive';
export const labelEnabled = 'Enabled';
export const labelDisabled = 'Disabled';
export const labelDeleteResourceAccessRule = 'Delete rule';
export const labelCancel = 'Cancel';
export const labelDeleteResourceAccessRuleDialogMessage =
  'is used to allow users to access resources.';
export const labelDeleteResourceAccessRuleWarning =
  'It will be permanently deleted and users will no longer have this permission.';
export const labelFailedToDeleteRule =
  'Failed to delete the resource access rule';
export const labelResourceAccessRuleDeletedSuccess =
  'The resource access rule has been successfully deleted';
export const labelDeleteMultipleResourceAccessRules =
  'Delete multiple resource access rules';
export const labelFailedToDeleteSelectedRules =
  'Failed to delete the selected resource access rules';
export const labelResourceAccessRulesDeletedSuccess =
  'The selected resource access rules have been deleted successfully';
export const labelDeleteResourceAccessRulesDialogMessage =
  'Rules are used to allow users to access resources.';
export const labelDeleteResourceAccessRulesWarning =
  'They will be permanently deleted and users will no longer have these permissions.';
export const labelDeleteResourceAccessRules = 'Delete rules';
export const labelDuplicate = 'Duplicate';
export const labelFailedToDuplicateRule =
  'Failed to duplicate the resource access rule';
export const labelRuleDuplicatedSuccess =
  'The resource access rule has been successfully duplicated';
export const labelResourceAccessRuleName = 'Resource access rule name';
export const labelEnterNameForDuplicatedRule =
  'Please enter a name for the duplicated resource access rule';
export const labelAllResources = 'All resources';
export const labelAllResourcesSelected = 'All resources selected';

==> centreon-web-24.10.15.tar.gz: centreon-web-24.10.15/www/front_src/src/ResourceAccessManagement/translatedLabels.ts <==
export const labelResourceAccessRules = 'Resource access rules';
export const labelName = 'Name';
export const labelDescription = 'Description';
export const labelActions = 'Actions';
export const labelStatus = 'Status';
export const labelSearch = 'Search';
export const labelAdd = 'Add';
export const labelCreateResourceAccessRule =
  'Create a new resource access rule';
export const labelEditResourceAccessRule = 'Edit resource access rule';
export const labelRuleProperies = 'Rule properties';
export const labelAddResourceDatasets = 'Add resource datasets';
export const labelContacts = 'Contacts';
export const labelContactGroups = 'Contact Groups';
export const labelContactsAndContactGroups = 'Contacts/Contact groups';
export const labelResourceAccessRuleAddedSuccess =
  'The resource access rule was successfully created';
export const labelResourceAccessRuleEditedSuccess =
  'The resource access rule was successfully updated';
export const labelRequired = 'Required';
export const labelNameAlreadyExists = 'This name already exists';
export const labelSave = 'Save';
export const labelExit = 'Exit';
export const labelAddNewDataset = 'Add new dataset';
export const labelAddFilter = 'Add filter';
export const labelChooseAtLeastOneContactOrContactGroup =
  'Choose at least one contact or contact group';
export const labelHost = 'Host';
export const labelHostCategory = 'Host category';
export const labelHostGroup = 'Host group';
export const labelMetaService = 'Metaservice';
export const labelService = 'Service';
export const labelServiceCategory = 'Service category';
export const labelServiceGroup = 'Service group';
export const labelPleaseSelectAResource = 'Please select a resource';
export const labelDelete = 'Delete';
export const labelSelectResourceType = 'Select resource type';
export const labelSelectResource = 'Select resource';
export const labelActiveOrInactive = 'Active / Inactive';
export const labelEnabled = 'Enabled';
export const labelDisabled = 'Disabled';
export const labelDeleteResourceAccessRule = 'Delete rule';
export const labelCancel = 'Cancel';
export const labelDeleteResourceAccessRuleDialogMessage =
  'is used to allow users to access resources.';
export const labelDeleteResourceAccessRuleWarning =
  'It will be permanently deleted and users will no longer have this permission.';
export const labelFailedToDeleteRule =
  'Failed to delete the resource access rule';
export const labelResourceAccessRuleDeletedSuccess =
  'The resource access rule has been successfully deleted';
export const labelDeleteMultipleResourceAccessRules =
  'Delete multiple resource access rules';
export const labelFailedToDeleteSelectedRules =
  'Failed to delete the selected resource access rules';
export const labelResourceAccessRulesDeletedSuccess =
  'The selected resource access rules have been deleted successfully';
export const labelDeleteResourceAccessRulesDialogMessage =
  'Rules are used to allow users to access resources.';
export const labelDeleteResourceAccessRulesWarning =
  'They will be permanently deleted and users will no longer have these permissions.';
export const labelDeleteResourceAccessRules = 'Delete rules';
export const labelDuplicate = 'Duplicate';
export const labelFailedToDuplicateRule =
  'Failed to duplicate the resource access rule';
export const labelRuleDuplicatedSuccess =
  'The resource access rule has been successfully duplicated';
export const labelResourceAccessRuleName = 'Resource access rule name';
export const labelEnterNameForDuplicatedRule =
  'Please enter a name for the duplicated resource access rule';
export const labelAllResources = 'All resources';
export const labelAllResourcesSelected = 'All resources selected';
export const labelAllHostsSelected = 'All hosts selected';
export const labelAllHostGroupsSelected = 'All host groups selected';
export const labelAllServiceGroupsSelected = 'All service groups selected';
export const labelAllHosts = 'All hosts';
export const labelAllHostGroups = 'All host groups';
export const labelAllServiceGroups = 'All service groups';
export const labelBusinessView = 'Business view';
export const labelAllBusinessViews = 'All business views';
export const labelAllBusinessViewsSelected = 'All business views selected';
export const labelAllContacts = 'All contacts';
export const labelAllContactsSelected = 'All contacts selected';
export const labelAllContactGroups = 'All contact groups';
export const labelAllContactGroupsSelected = 'All contact groups selected';
export const labelDoYouWantToQuitWithoutSaving =
  'Do you want to quit the form without saving the changes?';
export const labelYourFormHasUnsavedChanges = 'Your form has unsaved changes';
